@@ -311,3 +311,47 @@ test_that("monolix model creation without running", {
 
   })
 })
+
+
+test_that("monolix treatment of +var()", {
+
+  one.cmt <- function() {
+    ini({
+      tka <- 0.45 ; label("Ka")
+      tcl <- log(c(0, 2.7, 100)) ; label("Log Cl")
+      tv <- 3.45; label("log V")
+      cl.wt <- 0
+      v.wt <- 0
+      eta.ka ~ 0.6
+      eta.cl ~ 0.3
+      eta.v ~ 0.1
+      add.sd <- 0.7
+    })
+    model({
+      ka <- exp(tka + eta.ka)
+      cl <- exp(tcl + eta.cl + WT * cl.wt)
+      v <- exp(tv + eta.v)+ WT ^ 2 * v.wt
+      d/dt(depot) <- -depot*ka
+      d/dt(central) <- depot*ka - cl*central/v
+      cp <-central/v
+      cp ~ add(add.sd)
+    })
+  }
+
+  f <- one.cmt()
+
+  par <- strsplit(f$mlxtranParameter, "\n")[[1]]
+  par <- par[grepl("add__sd", par)]
+
+  expect_equal(par, "add__sd={value=0.7, method=MLE}")
+
+  f2 <- try(f %>% model({cp~add(add.sd) + var()}), silent=TRUE)
+  if (inherits(f2, "try-error")) {
+    skip("rxode2 doesn't support + var()")
+  } else {
+    par <- strsplit(f2$mlxtranParameter, "\n")[[1]]
+    par <- par[grepl("add__sd", par)]
+    expect_equal(par, paste0("add__sd={value=", sqrt(.7), ", method=MLE}"))
+  }
+
+})
